﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;
using System.Windows;
using System.Windows.Controls;
using System.Windows.Data;
using System.Windows.Documents;
using System.Windows.Input;
using System.Windows.Media;
using System.Windows.Media.Imaging;
using System.Windows.Navigation;
using System.Windows.Shapes;
using Syncfusion.Windows.Chart;
using System.Data;
using System.Collections;
using Syncfusion.Windows.Shared;

namespace ChartWithHugeDataSource
{
    /// <summary>
    /// Interaction logic for Window1.xaml
    /// </summary>
    public partial class Window1 : ChromelessWindow
    {
        #region Initialization
        /// <summary>
        /// Contrcutor for window1.
        /// </summary>      
        public Window1()
        {
            InitializeComponent();

            this.chart1.Areas[0].PrimaryAxis.IntersectAction = ChartLabelIntersectAction.Hide;
            InitializeChartData(100000);
        }
        #endregion

        #region Helper Methods
        #region InitializeChartData
        /// <summary>
        /// Initializes chart data from DataTable.
        /// </summary>
        protected void InitializeChartData(int totalXValues)
        {
            int yMax = 100;

            #region Range settings
            //Sets the value type and of the axes. Setting this ensures that the ranges stay consistent as you zoom into the chart.
            this.chart1.Areas[0].PrimaryAxis.IsAutoSetRange = false;
            this.chart1.Areas[0].PrimaryAxis.Range = new DoubleRange(0, totalXValues);
            this.chart1.Areas[0].PrimaryAxis.Interval = totalXValues / 10;

            this.chart1.Areas[0].SecondaryAxis.IsAutoSetRange = false;
            this.chart1.Areas[0].SecondaryAxis.Range = new DoubleRange(0, yMax);
            this.chart1.Areas[0].SecondaryAxis.Interval = yMax / 10;
            #endregion

            DataTable tableSource = this.CreateLargeTable(totalXValues, yMax);

            //Initializes new chart series.
            ChartSeries series = this.chart1.Areas[0].Series[0];
            // The DummyType that is used internally exposes these properties - XValue and YValue.
            series.BindingPathX = "XValue";
            series.BindingPathsY = new string[] { "YValue" };

            // Custom list that "averages" the large set of data points based on the current chart width. Instead of just skipping
            // points, this model uses an average of a set of points.
            // (Remember to set IsIndexed = false on this series (here it's done in the XAML)
            // This will also set this CompressedDataList as the DataSource for the series.
            CompressedDataList customList = new CompressedDataList(this.chart1, series, tableSource, "X", "Y");
                      
            customList.DilutionFactorChanged += new EventHandler(list_DilutionFactorChanged);
        }
        #endregion

        #region CreateLargeTable
        /// <summary>
        /// Method to create large table of data
        /// </summary>   
        private DataTable CreateLargeTable(int totalXValues, int yMax)
        {
            DataTable table = new DataTable();
            // It's important that the x values are marked as integer, otherwise, the engine will treat it as strings and
            // sort them incorrectly.
            DataColumn x = new DataColumn("X", typeof(Int32));
            table.Columns.Add(x);
            table.Columns.Add(new DataColumn("Y"));

            Random ran = new Random(DateTime.Now.Second);

            for (int i = 0; i < totalXValues; i++)
            {
                int xVal = i;
                double yVal = ((double)xVal / totalXValues) * yMax + ran.Next(-20, 20);
                DataRow row = table.NewRow();

                row[0] = xVal;
                row[1] = yVal;

                table.Rows.Add(row);
            }
            return table;
        }
        #endregion

        /// <summary>
        /// Method updates sub title when Dilution Factor is changed
        /// </summary>  
        private void UpdateSubtitle()
        {
            title.Text = "Compression Ratio - " +
                                                ((CompressedDataList)this.chart1.Areas[0].Series[0].DataSource).DilutionFactor.ToString() +
                                                " : 1";
        }
        #endregion

        #region Events
        /// <summary>
        /// Event triggered when dilution factor is changed
        /// </summary>  
        void list_DilutionFactorChanged(object sender, EventArgs e)
        {
            // Could happen when chart resizes
            this.UpdateSubtitle();
        }
        #endregion
    }
}
